@@ -286,11 +286,16 @@ public class AltosFlightSeries extends AltosDataListener {
 	}
 
 	private void compute_height() {
-		double ground_altitude = cal_data().ground_altitude;
-		if (height_series == null && ground_altitude != AltosLib.MISSING && altitude_series != null) {
-			height_series = add_series(height_name, AltosConvert.height);
-			for (AltosTimeValue alt : altitude_series)
-				height_series.add(alt.time, alt.value - ground_altitude);
+		if (height_series == null) {
+			double ground_altitude = cal_data().ground_altitude;
+			if (ground_altitude != AltosLib.MISSING && altitude_series != null) {
+				height_series = add_series(height_name, AltosConvert.height);
+				for (AltosTimeValue alt : altitude_series)
+					height_series.add(alt.time, alt.value - ground_altitude);
+			} else if (speed_series != null) {
+				height_series = add_series(height_name, AltosConvert.height);
+				speed_series.integrate(height_series);
+			}
 		}
 
 		if (gps_height == null && cal_data().gps_pad != null && cal_data().gps_pad.alt != AltosLib.MISSING && gps_altitude != null) {
@@ -343,8 +348,12 @@ public class AltosFlightSeries extends AltosDataListener {
 			else
 				accel_series.integrate(temp_series);
 
+			AltosTimeSeries clip_series = make_series(speed_name, AltosConvert.speed);
+
+			temp_series.clip(clip_series, 0, Double.POSITIVE_INFINITY);
+
 			accel_speed_series = make_series(speed_name, AltosConvert.speed);
-			temp_series.filter(accel_speed_series, 0.1);
+			clip_series.filter(accel_speed_series, 0.1);
 		}
 
 		if (alt_speed_series != null && accel_speed_series != null) {
@@ -401,6 +410,9 @@ public class AltosFlightSeries extends AltosDataListener {
 		if (cal_data.accel_zero_across == AltosLib.MISSING)
 			return;
 
+		if (cal_data.gyro_zero_roll == AltosLib.MISSING)
+			return;
+
 		AltosRotation rotation = new AltosRotation(accel_ground_across,
 							   accel_ground_through,
 							   accel_ground_along,
@@ -758,6 +770,16 @@ public class AltosFlightSeries extends AltosDataListener {
 	public void set_companion(AltosCompanion companion) {
 	}
 
+	public static final String motor_pressure_name = "Motor Pressure";
+
+	public AltosTimeSeries motor_pressure_series;
+
+	public void set_motor_pressure(double motor_pressure) {
+		if (motor_pressure_series == null)
+			motor_pressure_series = add_series(motor_pressure_name, AltosConvert.pressure);
+		motor_pressure_series.add(time(), motor_pressure);
+	}
+
 	public void finish() {
 		compute_orient();
 		if (speed_series == null) {
