@@ -393,7 +393,7 @@ public class AltosLaunchUI
 		if (!open())
 			return;
 
-		Container		pane = getContentPane();
+		Container		pane = getScrollablePane();
 		GridBagConstraints	c = new GridBagConstraints();
 		Insets			i = new Insets(4,4,4,4);
 
@@ -510,4 +510,4 @@ public class AltosLaunchUI
 
 		setVisible(true);
 	}
-}
\ No newline at end of file
+}
