@@ -47,7 +47,7 @@ static void usage(char *program)
 	exit(1);
 }
 
-void
+static void
 done(struct cc_usb *cc, int code)
 {
 /*	cc_usb_printf(cc, "a\n"); */
@@ -55,28 +55,6 @@ done(struct cc_usb *cc, int code)
 	exit (code);
 }
 
-static int
-ends_with(char *whole, char *suffix)
-{
-	int whole_len = strlen(whole);
-	int suffix_len = strlen(suffix);
-
-	if (suffix_len > whole_len)
-		return 0;
-	return strcmp(whole + whole_len - suffix_len, suffix) == 0;
-}
-
-static int
-starts_with(char *whole, char *prefix)
-{
-	int whole_len = strlen(whole);
-	int prefix_len = strlen(prefix);
-
-	if (prefix_len > whole_len)
-		return 0;
-	return strncmp(whole, prefix, prefix_len) == 0;
-}
-
 static char **
 tok(char *line) {
 	char	**strs = malloc (sizeof (char *)), *str;
@@ -140,16 +118,15 @@ free_gps(struct gps *b) {
 	}
 }
 
-char **
+static char **
 find_gps(struct gps *b, char *word0) {
-	int i;
 	for (;b; b = b->next)
 		if (b->strs[0] && !strcmp(b->strs[0], word0))
 			return b->strs;
 	return NULL;
 }
 
-int
+static int
 do_gps(struct cc_usb *usb) {
 	int	count = 0;
 
@@ -186,15 +163,9 @@ int
 main (int argc, char **argv)
 {
 	char			*device = NULL;
-	char			*filename;
-	Elf			*e;
-	unsigned int		s;
-	int			i;
 	int			c;
-	int			tries;
 	struct cc_usb		*cc = NULL;
 	char			*tty = NULL;
-	int			success;
 	int			verbose = 0;
 	int			ret = 0;
 
