@@ -20,22 +20,23 @@
 #include <ao_adc_fast.h>
 #include <ao_crc.h>
 #include <ao_trng_send.h>
-#include <ao_flash_readout.h>
 
 void main(void)
 {
-	ao_led_init();
+	ao_led_init(LEDS_AVAILABLE);
+	ao_led_on(AO_LED_RED);
 	ao_clock_init();
 	ao_task_init();
 	ao_timer_init();
 	ao_dma_init();
 	ao_adc_init();
 	ao_crc_init();
-	ao_flash_readout_init();
 
 	ao_usb_init();
 
 	ao_trng_send_init();
 
+	ao_led_off(AO_LED_RED);
+
 	ao_start_scheduler();
 }
