@@ -46,7 +46,7 @@ void
 ao_lco_show_pad(uint8_t pad)
 {
 	ao_mutex_get(&ao_lco_display_mutex);
-	ao_seven_segment_set(AO_LCO_PAD_DIGIT, pad | (ao_lco_drag_race << 4));
+	ao_seven_segment_set(AO_LCO_PAD_DIGIT, (uint8_t) (pad | (ao_lco_drag_race << 4)));
 	ao_mutex_put(&ao_lco_display_mutex);
 }
 
@@ -72,11 +72,11 @@ ao_lco_show_box(uint16_t box)
 {
 	ao_mutex_get(&ao_lco_display_mutex);
 	if (box == AO_LCO_BOX_DRAG) {
-		ao_seven_segment_direct(AO_LCO_BOX_DIGIT_10, SEVEN_SEGMENT_d | (ao_lco_drag_race << 7));
-		ao_seven_segment_direct(AO_LCO_BOX_DIGIT_1, SEVEN_SEGMENT_r | (ao_lco_drag_race << 7));
+		ao_seven_segment_direct(AO_LCO_BOX_DIGIT_10, (uint8_t) (SEVEN_SEGMENT_d | (ao_lco_drag_race << 7)));
+		ao_seven_segment_direct(AO_LCO_BOX_DIGIT_1, (uint8_t) (SEVEN_SEGMENT_r | (ao_lco_drag_race << 7)));
 	} else {
-		ao_seven_segment_set(AO_LCO_BOX_DIGIT_1, box % 10 | (ao_lco_drag_race << 4));
-		ao_seven_segment_set(AO_LCO_BOX_DIGIT_10, box / 10 | (ao_lco_drag_race << 4));
+		ao_seven_segment_set(AO_LCO_BOX_DIGIT_1, (uint8_t) (box % 10 | (ao_lco_drag_race << 4)));
+		ao_seven_segment_set(AO_LCO_BOX_DIGIT_10, (uint8_t) (box / 10 | (ao_lco_drag_race << 4)));
 	}
 	ao_mutex_put(&ao_lco_display_mutex);
 }
@@ -86,9 +86,9 @@ ao_lco_show_voltage(uint16_t decivolts)
 {
 	uint8_t	tens, ones, tenths;
 
-	tenths = decivolts % 10;
-	ones = (decivolts / 10) % 10;
-	tens = (decivolts / 100) % 10;
+	tenths = (uint8_t) (decivolts % 10);
+	ones = (uint8_t) ((decivolts / 10) % 10);
+	tens = (uint8_t) ((decivolts / 100) % 10);
 	ao_mutex_get(&ao_lco_display_mutex);
 	ao_seven_segment_set(AO_LCO_PAD_DIGIT, tenths);
 	ao_seven_segment_set(AO_LCO_BOX_DIGIT_1, ones | 0x10);
@@ -127,7 +127,7 @@ static uint8_t		ao_lco_drag_active;
 static AO_TICK_TYPE
 ao_lco_drag_button_check(AO_TICK_TYPE now, AO_TICK_TYPE delay)
 {
-	AO_TICK_TYPE	button_delay = ~0;
+	AO_TICK_TYPE	button_delay = ~0UL;
 
 	/*
 	 * Check to see if the button has been held down long enough
@@ -135,14 +135,14 @@ ao_lco_drag_button_check(AO_TICK_TYPE now, AO_TICK_TYPE delay)
 	 */
 	if (ao_lco_fire_down) {
 		if (ao_lco_drag_race) {
-			if ((AO_TICK_SIGNED) (now - ao_lco_fire_tick) >= AO_LCO_DRAG_RACE_STOP_TIME) {
+			if ((AO_TICK_SIGNED) (now - ao_lco_fire_tick) >= (AO_TICK_SIGNED) AO_LCO_DRAG_RACE_STOP_TIME) {
 				ao_lco_drag_disable();
 				ao_lco_fire_down = 0;
 			}
 			else
 				button_delay = ao_lco_fire_tick + AO_LCO_DRAG_RACE_STOP_TIME - now;
 		} else {
-			if ((AO_TICK_SIGNED) (now - ao_lco_fire_tick) >= AO_LCO_DRAG_RACE_START_TIME) {
+			if ((AO_TICK_SIGNED) (now - ao_lco_fire_tick) >= (AO_TICK_SIGNED) AO_LCO_DRAG_RACE_START_TIME) {
 				ao_lco_drag_enable();
 				ao_lco_fire_down = 0;
 			}
@@ -158,7 +158,7 @@ ao_lco_drag_button_check(AO_TICK_TYPE now, AO_TICK_TYPE delay)
 static void
 ao_lco_drag_monitor(void)
 {
-	AO_TICK_TYPE	delay = ~0;
+	AO_TICK_TYPE	delay = ~0UL;
 	AO_TICK_TYPE	now;
 
 	ao_beep_for(AO_BEEP_MID, AO_MS_TO_TICKS(200));
@@ -170,7 +170,7 @@ ao_lco_drag_monitor(void)
 		else
 			ao_sleep_for(&ao_lco_drag_beep_count, delay);
 
-		delay = ~0;
+		delay = ~0UL;
 		if (!ao_lco_drag_active)
 			continue;
 
@@ -181,7 +181,7 @@ ao_lco_drag_monitor(void)
 
 		/* check to see if there's anything left to do here */
 		if (!ao_lco_fire_down && !ao_lco_drag_race && !ao_lco_drag_beep_count) {
-			delay = ~0;
+			delay = ~0UL;
 			ao_lco_drag_active = 0;
 		}
 	}
@@ -190,7 +190,7 @@ ao_lco_drag_monitor(void)
 static void
 ao_lco_step_box(int8_t dir)
 {
-	int16_t new_box = ao_lco_box;
+	int32_t new_box = (int32_t) ao_lco_box;
 	do {
 		if (new_box == AO_LCO_BOX_DRAG) {
 			if (dir < 0)
@@ -204,10 +204,10 @@ ao_lco_step_box(int8_t dir)
 			else if (new_box < ao_lco_min_box)
 				new_box = AO_LCO_BOX_DRAG;
 		}
-		if (new_box == ao_lco_box)
+		if (new_box == (int32_t) ao_lco_box)
 			break;
-	} while (!ao_lco_box_present(new_box));
-	ao_lco_set_box(new_box);
+	} while (!ao_lco_box_present((uint16_t) new_box));
+	ao_lco_set_box((uint16_t) new_box);
 }
 
 static void
@@ -235,12 +235,12 @@ ao_lco_input(void)
 		case AO_EVENT_BUTTON:
 			switch (event.unit) {
 			case AO_BUTTON_ARM:
-				ao_lco_set_armed(event.value);
+				ao_lco_set_armed((uint8_t) event.value);
 				break;
 			case AO_BUTTON_FIRE:
 				if (ao_lco_armed) {
 					ao_lco_fire_down = 0;
-					ao_lco_set_firing(event.value);
+					ao_lco_set_firing((uint8_t) event.value);
 				} else {
 					if (event.value) {
 						if (ao_lco_box == AO_LCO_BOX_DRAG) {
@@ -290,7 +290,7 @@ ao_lco_batt_voltage(void)
 
 	ao_adc_single_get(&packet);
 	decivolt = ao_battery_decivolt(packet.v_batt);
-	ao_lco_show_voltage(decivolt);
+	ao_lco_show_voltage((uint16_t) decivolt);
 	ao_delay(AO_MS_TO_TICKS(1000));
 }
 #endif
@@ -319,7 +319,7 @@ ao_lco_main(void)
 static void
 ao_lco_set_debug(void)
 {
-	uint16_t r  = ao_cmd_decimal();
+	uint32_t r  = ao_cmd_decimal();
 	if (ao_cmd_status == ao_cmd_success)
 		ao_lco_debug = r != 0;
 }
