@@ -176,7 +176,7 @@ _ao_mpu9250_sample(struct ao_mpu9250_sample *sample)
 	/* byte swap */
 	while (i--) {
 		uint16_t	t = *d;
-		*d++ = (t >> 8) | (t << 8);
+		*d++ = (uint16_t) ((uint16_t) (t >> 8) | (uint16_t) (t << 8));
 	}
 #endif
 }
