@@ -20,12 +20,12 @@
 #define _AO_PINS_H_
 
 
-/* 16MHz High speed external crystal */
-#define AO_HSE			16000000
+/* 8MHz High speed external crystal */
+#define AO_HSE			8000000
 
 /* PLLVCO = 96MHz (so that USB will work) */
-#define AO_PLLMUL		6
-#define AO_RCC_CFGR_PLLMUL	(STM_RCC_CFGR_PLLMUL_6)
+#define AO_PLLMUL		12
+#define AO_RCC_CFGR_PLLMUL	(STM_RCC_CFGR_PLLMUL_12)
 
 /* SYSCLK = 32MHz (no need to go faster than CPU) */
 #define AO_PLLDIV		3
@@ -68,7 +68,7 @@
 #define AO_CONFIG_MAX_SIZE                     1024
 #define LOG_ERASE_MARK                         0x55
 #define LOG_MAX_ERASE                          128
-#define AO_LOG_FORMAT				AO_LOG_FORMAT_EASYMEGA_2
+#define AO_LOG_FORMAT				AO_LOG_FORMAT_TELEMEGA
 
 #define HAS_EEPROM		1
 #define USE_INTERNAL_FLASH	0
@@ -76,10 +76,10 @@
 #define USE_STORAGE_CONFIG	0
 #define HAS_USB			1
 #define HAS_BEEP		1
-#define BEEPER_TIMER		2
-#define BEEPER_CHANNEL		3
-#define BEEPER_PORT		(&stm_gpioa)
-#define BEEPER_PIN		2
+#define BEEPER_TIMER		3
+#define BEEPER_CHANNEL		1
+#define BEEPER_PORT		(&stm_gpioc)
+#define BEEPER_PIN		6
 #define HAS_BATTERY_REPORT	1
 #define HAS_RADIO		0
 #define HAS_TELEMETRY		0
@@ -88,15 +88,20 @@
 
 #define HAS_SPI_1		1
 #define SPI_1_PA5_PA6_PA7	1	/* Barometer */
-#define SPI_1_PB3_PB4_PB5	1	/* Accelerometer */
+#define SPI_1_PB3_PB4_PB5	1	/* Accelerometer, Gyro */
 #define SPI_1_PE13_PE14_PE15	0
 #define SPI_1_OSPEEDR		STM_OSPEEDR_10MHz
 
 #define HAS_SPI_2		1
-#define SPI_2_PB13_PB14_PB15	1	/* Flash, IMU, Companion */
+#define SPI_2_PB13_PB14_PB15	1	/* Flash, Companion */
 #define SPI_2_PD1_PD3_PD4	0
 #define SPI_2_OSPEEDR		STM_OSPEEDR_10MHz
 
+#define SPI_2_PORT		(&stm_gpiob)
+#define SPI_2_SCK_PIN		13
+#define SPI_2_MISO_PIN		14
+#define SPI_2_MOSI_PIN		15
+
 #define HAS_I2C_1		1
 #define I2C_1_PB8_PB9		1
 
@@ -294,44 +299,35 @@ struct ao_adc {
 #define AO_M25_SPI_BUS		AO_SPI_2_PB13_PB14_PB15
 
 /*
- * bmx160
+ * Mag sensor (hmc5883)
  */
 
-#define HAS_BMX160		1
-#define AO_BMX160_INT_PORT	(&stm_gpioc)
-#define AO_BMX160_INT_PIN	15
-#define AO_BMX160_SPI_BUS	(AO_SPI_2_PB13_PB14_PB15 | AO_SPI_MODE_0)
-#define AO_BMX160_SPI_CS_PORT	(&stm_gpioc)
-#define AO_BMX160_SPI_CS_PIN	13
+#define HAS_HMC5883		1
+#define AO_HMC5883_INT_PORT	(&stm_gpioc)
+#define AO_HMC5883_INT_PIN	14
+#define AO_HMC5883_I2C_INDEX	STM_I2C_INDEX(1)
+
+/*
+ * mpu6000
+ */
+
+#define HAS_MPU6000		1
+#define AO_MPU6000_INT_PORT	(&stm_gpioc)
+#define AO_MPU6000_INT_PIN	15
+#define AO_MPU6000_SPI_BUS	AO_SPI_1_PB3_PB4_PB5
+#define AO_MPU6000_SPI_CS_PORT	(&stm_gpioc)
+#define AO_MPU6000_SPI_CS_PIN	13
 #define HAS_IMU			1
 
-#define ao_data_along(packet)	((packet)->bmx160.acc_x)
-#define ao_data_across(packet)	(-(packet)->bmx160.acc_y)
-#define ao_data_through(packet)	((packet)->bmx160.acc_z)
+/*
+ * mma655x
+ */
 
-#define ao_data_roll(packet)	((packet)->bmx160.gyr_x)
-#define ao_data_pitch(packet)	(-(packet)->bmx160.gyr_y)
-#define ao_data_yaw(packet)	((packet)->bmx160.gyr_z)
-
-#define ao_data_mag_along(packet)	((packet)->bmx160.mag_x)
-#define ao_data_mag_across(packet)	(-(packet)->bmx160.mag_y)
-#define ao_data_mag_through(packet)	((packet)->bmx160.mag_z)
-
-/* ADXL375 */
-
-#define HAS_ADXL375		1
-#define AO_ADXL375_SPI_INDEX	(AO_SPI_1_PB3_PB4_PB5 | AO_SPI_MODE_3)
-#define AO_ADXL375_CS_PORT	(&stm_gpioc)
-#define AO_ADXL375_CS_PIN	12
-
-#define AO_ADXL375_INT1_PORT	(&stm_gpiob)
-#define AO_ADXL375_INT1_PIN	8
-
-#define AO_ADXL375_INT2_PORT	(&stm_gpiob)
-#define AO_ADXL375_INT2_PIN	9
-
-#define AO_ADXL375_AXIS		x
-#define AO_ADXL375_INVERT	1
+#define HAS_MMA655X		1
+#define AO_MMA655X_INVERT	0
+#define AO_MMA655X_SPI_INDEX	AO_SPI_1_PB3_PB4_PB5
+#define AO_MMA655X_CS_PORT	(&stm_gpioc)
+#define AO_MMA655X_CS_PIN	12
 
 #define NUM_CMDS		16
 
