@@ -32,7 +32,7 @@ typedef uint8_t check_log_size[1-(256 % sizeof(struct ao_log_record))] ;
 void
 ao_log(void)
 {
-	uint16_t	next_sensor, next_other;
+	AO_TICK_TYPE	next_sensor, next_other;
 
 	ao_storage_setup();
 
@@ -58,18 +58,19 @@ ao_log(void)
 	for (;;) {
 		/* Write samples to EEPROM */
 		while (ao_log_data_pos != ao_sample_data) {
-			ao_log_data.tick = ao_data_ring[ao_log_data_pos].tick;
-			if ((int16_t) (ao_log_data.tick - next_sensor) >= 0) {
+			AO_TICK_TYPE tick = ao_data_ring[ao_log_data_pos].tick;
+			ao_log_data.tick = tick;
+			if ((AO_TICK_SIGNED) (tick - next_sensor) >= 0) {
 				ao_log_data.type = AO_LOG_SENSOR;
 				ao_log_data.u.sensor.accel = ao_data_ring[ao_log_data_pos].adc.accel;
 				ao_log_data.u.sensor.pres = ao_data_ring[ao_log_data_pos].adc.pres;
 				ao_log_write(&ao_log_data);
 				if (ao_log_state <= ao_flight_coast)
-					next_sensor = ao_log_data.tick + AO_SENSOR_INTERVAL_ASCENT;
+					next_sensor = tick + AO_SENSOR_INTERVAL_ASCENT;
 				else
-					next_sensor = ao_log_data.tick + AO_SENSOR_INTERVAL_DESCENT;
+					next_sensor = tick + AO_SENSOR_INTERVAL_DESCENT;
 			}
-			if ((int16_t) (ao_log_data.tick - next_other) >= 0) {
+			if ((AO_TICK_SIGNED) (tick - next_other) >= 0) {
 				ao_log_data.type = AO_LOG_TEMP_VOLT;
 				ao_log_data.u.temp_volt.temp = ao_data_ring[ao_log_data_pos].adc.temp;
 				ao_log_data.u.temp_volt.v_batt = ao_data_ring[ao_log_data_pos].adc.v_batt;
@@ -78,7 +79,7 @@ ao_log(void)
 				ao_log_data.u.deploy.drogue = ao_data_ring[ao_log_data_pos].adc.sense_d;
 				ao_log_data.u.deploy.main = ao_data_ring[ao_log_data_pos].adc.sense_m;
 				ao_log_write(&ao_log_data);
-				next_other = ao_log_data.tick + AO_OTHER_INTERVAL;
+				next_other = tick + AO_OTHER_INTERVAL;
 			}
 			ao_log_data_pos = ao_data_ring_next(ao_log_data_pos);
 		}
