@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017 Keith Packard <keithp@keithp.com>
+ * Copyright © 2012 Keith Packard <keithp@keithp.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,12 +20,12 @@
 #define _AO_PINS_H_
 
 
-/* 16MHz High speed external crystal */
-#define AO_HSE			16000000
+/* 8MHz High speed external crystal */
+#define AO_HSE			8000000
 
 /* PLLVCO = 96MHz (so that USB will work) */
-#define AO_PLLMUL		6
-#define AO_RCC_CFGR_PLLMUL	(STM_RCC_CFGR_PLLMUL_6)
+#define AO_PLLMUL		12
+#define AO_RCC_CFGR_PLLMUL	(STM_RCC_CFGR_PLLMUL_12)
 
 /* SYSCLK = 32MHz (no need to go faster than CPU) */
 #define AO_PLLDIV		3
@@ -43,35 +43,32 @@
 #define AO_APB2_PRESCALER	2
 #define AO_RCC_CFGR_PPRE2_DIV	STM_RCC_CFGR_PPRE2_DIV_2
 
-#define HAS_SERIAL_1		0
+#define HAS_SERIAL_1		1
 #define USE_SERIAL_1_STDIN	0
 #define SERIAL_1_PB6_PB7	0
-#define SERIAL_1_PA9_PA10	0
+#define SERIAL_1_PA9_PA10	1
 
-#define HAS_SERIAL_2		1
+#define HAS_SERIAL_2		0
 #define USE_SERIAL_2_STDIN	0
-#define SERIAL_2_PA2_PA3	1
+#define SERIAL_2_PA2_PA3	0
 #define SERIAL_2_PD5_PD6	0
-#define USE_SERIAL_2_FLOW	0
-#define USE_SERIAL_2_SW_FLOW	0
 
-#define HAS_SERIAL_3		0
+#define HAS_SERIAL_3		1
 #define USE_SERIAL_3_STDIN	0
 #define SERIAL_3_PB10_PB11	0
-#define SERIAL_3_PC10_PC11	0
+#define SERIAL_3_PC10_PC11	1
 #define SERIAL_3_PD8_PD9	0
 
-#define ao_gps_getchar		ao_serial2_getchar
-#define ao_gps_putchar		ao_serial2_putchar
-#define ao_gps_set_speed	ao_serial2_set_speed
-#define ao_gps_fifo		(ao_stm_usart2.rx_fifo)
+#define ao_gps_getchar		ao_serial3_getchar
+#define ao_gps_putchar		ao_serial3_putchar
+#define ao_gps_set_speed	ao_serial3_set_speed
+#define ao_gps_fifo		(ao_stm_usart3.rx_fifo)
 
 #define AO_CONFIG_DEFAULT_FLIGHT_LOG_MAX	(1024 * 1024)
 #define AO_CONFIG_MAX_SIZE			1024
 #define LOG_ERASE_MARK				0x55
 #define LOG_MAX_ERASE				128
-#define AO_LOG_FORMAT				AO_LOG_FORMAT_TELEMEGA_6
-#define AO_LOG_NORMALIZED			1
+#define AO_LOG_FORMAT				AO_LOG_FORMAT_TELEMEGA
 
 #define HAS_EEPROM		1
 #define USE_INTERNAL_FLASH	0
@@ -80,9 +77,9 @@
 #define HAS_USB			1
 #define HAS_BEEP		1
 #define BEEPER_TIMER		3
-#define BEEPER_CHANNEL		2
-#define BEEPER_PORT		(&stm_gpioe)
-#define BEEPER_PIN		4
+#define BEEPER_CHANNEL		1
+#define BEEPER_PORT		(&stm_gpioc)
+#define BEEPER_PIN		6
 #define HAS_BATTERY_REPORT	1
 #define HAS_RADIO		1
 #define HAS_TELEMETRY		1
@@ -91,24 +88,25 @@
 
 #define HAS_SPI_1		1
 #define SPI_1_PA5_PA6_PA7	1	/* Barometer */
-#define SPI_1_PB3_PB4_PB5	1	/* Accelerometer */
-#define SPI_1_PE13_PE14_PE15	1	/* MPU6000 */
+#define SPI_1_PB3_PB4_PB5	0
+#define SPI_1_PE13_PE14_PE15	1	/* Accelerometer */
 #define SPI_1_OSPEEDR		STM_OSPEEDR_10MHz
 
-//#define MMC5983_I2C		1
-
 #define HAS_SPI_2		1
 #define SPI_2_PB13_PB14_PB15	1	/* Flash, Companion */
-#ifndef MMC5983_I2C
-#define SPI_2_PD1_PD3_PD4	1	/* MMC5983 */
-#endif
+#define SPI_2_PD1_PD3_PD4	0
 #define SPI_2_OSPEEDR		STM_OSPEEDR_10MHz
 
-#define HAS_I2C_1		0
-#define I2C_1_PB8_PB9		0
+#define SPI_2_PORT		(&stm_gpiob)
+#define SPI_2_SCK_PIN		13
+#define SPI_2_MISO_PIN		14
+#define SPI_2_MOSI_PIN		15
 
-#define HAS_I2C_2		0
-#define I2C_2_PB10_PB11		0
+#define HAS_I2C_1		1
+#define I2C_1_PB8_PB9		1
+
+#define HAS_I2C_2		1
+#define I2C_2_PB10_PB11		1
 
 #define PACKET_HAS_SLAVE	1
 #define PACKET_HAS_MASTER	0
@@ -152,12 +150,12 @@
 #define AO_PYRO_PIN_1	7
 
 /* Pyro C */
-#define AO_PYRO_PORT_2	(&stm_gpioe)
-#define AO_PYRO_PIN_2	3
+#define AO_PYRO_PORT_2	(&stm_gpiob)
+#define AO_PYRO_PIN_2	5
 
 /* Pyro D */
 #define AO_PYRO_PORT_3	(&stm_gpioe)
-#define AO_PYRO_PIN_3	2
+#define AO_PYRO_PIN_3	4
 
 /* Drogue */
 #define AO_IGNITER_DROGUE_PORT	(&stm_gpioe)
@@ -198,13 +196,13 @@ struct ao_adc {
 #define AO_ADC_SENSE_B_PORT	(&stm_gpioa)
 #define AO_ADC_SENSE_B_PIN	1
 
-#define AO_ADC_SENSE_C		24
-#define AO_ADC_SENSE_C_PORT	(&stm_gpioe)
-#define AO_ADC_SENSE_C_PIN	9
+#define AO_ADC_SENSE_C		2
+#define AO_ADC_SENSE_C_PORT	(&stm_gpioa)
+#define AO_ADC_SENSE_C_PIN	2
 
-#define AO_ADC_SENSE_D		25
-#define AO_ADC_SENSE_D_PORT	(&stm_gpioe)
-#define AO_ADC_SENSE_D_PIN	10
+#define AO_ADC_SENSE_D		3
+#define AO_ADC_SENSE_D_PORT	(&stm_gpioa)
+#define AO_ADC_SENSE_D_PIN	3
 
 #define AO_ADC_SENSE_DROGUE	4
 #define AO_ADC_SENSE_DROGUE_PORT	(&stm_gpioa)
@@ -296,134 +294,64 @@ struct ao_adc {
 
 #define M25_MAX_CHIPS		1
 #define AO_M25_SPI_CS_PORT	(&stm_gpiod)
-#define AO_M25_SPI_CS_MASK	(1 << 10)
+#define AO_M25_SPI_CS_MASK	(1 << 3)
 #define AO_M25_SPI_BUS		AO_SPI_2_PB13_PB14_PB15
 
 /*
- * Radio (cc1200)
+ * Radio (cc1120)
  */
 
 /* gets pretty close to 434.550 */
 
-#define AO_RADIO_CAL_DEFAULT 	5695733
+#define AO_RADIO_CAL_DEFAULT 	0x6ca333
 
 #define AO_FEC_DEBUG		0
-#define AO_CC1200_SPI_CS_PORT	(&stm_gpioc)
-#define AO_CC1200_SPI_CS_PIN	5
-#define AO_CC1200_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
-#define AO_CC1200_SPI		stm_spi2
+#define AO_CC1120_SPI_CS_PORT	(&stm_gpioc)
+#define AO_CC1120_SPI_CS_PIN	5
+#define AO_CC1120_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
+#define AO_CC1120_SPI		stm_spi2
 
-#define AO_CC1200_INT_PORT		(&stm_gpiob)
-#define AO_CC1200_INT_PIN		11
+#define AO_CC1120_INT_PORT		(&stm_gpioc)
+#define AO_CC1120_INT_PIN		14
+#define AO_CC1120_MCU_WAKEUP_PORT	(&stm_gpioc)
+#define AO_CC1120_MCU_WAKEUP_PIN	(0)
 
-#define AO_CC1200_INT_GPIO	2
-#define AO_CC1200_INT_GPIO_IOCFG	CC1200_IOCFG2
+#define AO_CC1120_INT_GPIO	2
+#define AO_CC1120_INT_GPIO_IOCFG	CC1120_IOCFG2
 
-#define AO_CC1200_MARC_GPIO	3
-#define AO_CC1200_MARC_GPIO_IOCFG	CC1200_IOCFG3
+#define AO_CC1120_MARC_GPIO	3
+#define AO_CC1120_MARC_GPIO_IOCFG	CC1120_IOCFG3
 
 #define HAS_BOOT_RADIO		0
 
-
 /*
- *
- * Here are the required sensor signs:
- *
- * +along	nose up
- * +across 	USB down
- * +through	TH down
- *
- * With the board aligned to have positive accel for the relevant
- * axis, looking down from above we have:
- *
- * +roll	counter clockwise (nose up)
- * +pitch	counter clockwise (USB down)
- * +yaw		counter clockwise (TH down)
+ * Mag sensor (hmc5883)
  */
 
+#define HAS_HMC5883		0
+#define AO_HMC5883_INT_PORT	(&stm_gpioc)
+#define AO_HMC5883_INT_PIN	12
+#define AO_HMC5883_I2C_INDEX	STM_I2C_INDEX(1)
+
 /*
- * On TMega v6, bmi088 pin 1 (NE corner of chip) is placed towards the
- * USB and antenna edges of the board. Relative to bmi088 specs, to
- * get the above values, we need to flip the Y axis, assigning values
- * as follows:
- *
- *	+along		+X	+roll	+X
- *	+across		-Y	+pitch	-Y
- *	+through	+Z	+yaw	+Z
+ * mpu6000
  */
 
-#define HAS_BMI088		1
-#define AO_BMI088_SPI_BUS	AO_SPI_1_PE13_PE14_PE15
-#define AO_BMI088_ACC_CS_PORT	(&stm_gpioc)
-#define AO_BMI088_ACC_CS_PIN	14
-#define AO_BMI088_GYR_CS_PORT	(&stm_gpioc)
-#define AO_BMI088_GYR_CS_PIN	13
+#define HAS_MPU6000		1	
+#define AO_MPU6000_INT_PORT	(&stm_gpioc)
+#define AO_MPU6000_INT_PIN	13
+#define AO_MPU6000_I2C_INDEX	STM_I2C_INDEX(1)
 #define HAS_IMU			1
 
-#define ao_bmi088_along(m)	((m)->acc.x)
-#define ao_bmi088_across(m)	(-(m)->acc.y)
-#define ao_bmi088_through(m)	((m)->acc.z)
-
-#define ao_bmi088_roll(m)	((m)->gyr.x)
-#define ao_bmi088_pitch(m)	(-(m)->gyr.y)
-#define ao_bmi088_yaw(m)	((m)->gyr.z)
-
-#define ao_data_along(packet)	ao_bmi088_along(&(packet)->bmi088)
-#define ao_data_across(packet)	ao_bmi088_across(&(packet)->bmi088)
-#define ao_data_through(packet)	ao_bmi088_through(&(packet)->bmi088)
-
-#define ao_data_roll(packet)	ao_bmi088_roll(&(packet)->bmi088)
-#define ao_data_pitch(packet)	ao_bmi088_pitch(&(packet)->bmi088)
-#define ao_data_yaw(packet)	ao_bmi088_yaw(&(packet)->bmi088)
-
 /*
- * MMC5983
- *
- *	pin 1 NE corner of chip
- *
- *	+along		-Y
- *	+across		+X
- *	+through	-Z
+ * mma655x
  */
 
-#define HAS_MMC5983		1
-#define AO_MMC5983_INT_PORT	(&stm_gpiod)
-#define AO_MMC5983_INT_PIN	5
-#define AO_MMC5983_SPI_CLK_PORT	(&stm_gpiod)
-#define AO_MMC5983_SPI_CLK_PIN	1
-#define AO_MMC5983_SPI_MISO_PORT	(&stm_gpiod)
-#define AO_MMC5983_SPI_MISO_PIN	3
-#define AO_MMC5983_SPI_MOSI_PORT	(&stm_gpiod)
-#define AO_MMC5983_SPI_MOSI_PIN	4
-#define AO_MMC5983_SPI_INDEX	(AO_SPI_2_PD1_PD3_PD4 | AO_SPI_MODE_3)
-#define AO_MMC5983_SPI_CS_PORT	(&stm_gpioa)
-#define AO_MMC5983_SPI_CS_PIN	15
-
-#define ao_mmc5983_along(m)		(-(m)->y)
-#define ao_mmc5983_across(m)		((m)->x)
-#define ao_mmc5983_through(m)		(-(m)->z)
-
-#define ao_data_mag_along(packet)	ao_mmc5983_along(&(packet)->mmc5983)
-#define ao_data_mag_across(packet)	ao_mmc5983_across(&(packet)->mmc5983)
-#define ao_data_mag_through(packet)	ao_mmc5983_through(&(packet)->mmc5983)
-
-/*
- * ADXL375
- *
- * pin 1 NW corner of chip
- *
- *	+along		+X
- *	+across		+Y
- *	+through	+Z
- */
-
-#define HAS_ADXL375		1
-#define AO_ADXL375_SPI_INDEX	(AO_SPI_1_PB3_PB4_PB5 | AO_SPI_MODE_3)
-#define AO_ADXL375_CS_PORT	(&stm_gpioc)
-#define AO_ADXL375_CS_PIN	0
-
-#define AO_ADXL375_AXIS		x
-#define AO_ADXL375_INVERT	1
+#define HAS_MMA655X		1
+#define AO_MMA655X_INVERT	0
+#define AO_MMA655X_SPI_INDEX	AO_SPI_1_PE13_PE14_PE15
+#define AO_MMA655X_CS_PORT	(&stm_gpiod)
+#define AO_MMA655X_CS_PIN	4
 
 #define NUM_CMDS		16
 
@@ -431,10 +359,8 @@ struct ao_adc {
  * Companion
  */
 
-#define AO_COMPANION_CS_PORT	(&stm_gpiob)
-#define AO_COMPANION_CS_PIN_0	(6)
-#define AO_COMPANION_CS_PIN	AO_COMPANION_CS_PIN_0
-#define AO_COMPANION_CS_PIN_1	(7)
+#define AO_COMPANION_CS_PORT	(&stm_gpiod)
+#define AO_COMPANION_CS_PIN	(0)
 #define AO_COMPANION_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
 
 /*
@@ -455,26 +381,4 @@ struct ao_adc {
 #define AO_PROFILE	       	0
 #endif
 
-/*
- * PWM output
- */
-
-#define NUM_PWM			4
-#define PWM_MAX			20000
-#define AO_PWM_TIMER		stm_tim4
-#define AO_PWM_TIMER_ENABLE	STM_RCC_APB1ENR_TIM4EN
-#define AO_PWM_TIMER_SCALE	32
-
-#define AO_PWM_0_GPIO		(&stm_gpiod)
-#define AO_PWM_0_PIN		12
-
-#define AO_PWM_1_GPIO		(&stm_gpiod)
-#define AO_PWM_1_PIN		13
-
-#define AO_PWM_2_GPIO		(&stm_gpiod)
-#define AO_PWM_2_PIN		15
-
-#define AO_PWM_3_GPIO		(&stm_gpiod)
-#define AO_PWM_3_PIN		14
-
 #endif /* _AO_PINS_H_ */
